@@ -1,8 +1,8 @@
 """Tests for the hush package."""
 
-from hush import get_secret
+from hush import Hush, get_secret
 
-from .conftest import FOO, KUNG_FOO
+from .conftest import FOO
 
 
 def test_get_secret__PASS(mock_pass: None) -> None:
@@ -12,8 +12,13 @@ def test_get_secret__PASS(mock_pass: None) -> None:
     secret = get_secret("foo")
     assert secret == FOO
 
-    secret = get_secret("foo", namespace=["path", "to"])
-    assert secret == KUNG_FOO
+    namespace = ["path", "to"]
+    secret = get_secret("foo", namespace=namespace)
+    assert secret == FOO
+
+    hush = Hush(namespace=namespace)
+    secret = hush.get_secret("foo")
+    assert secret == FOO
 
 
 def test_get_secret__ENVVAR(mock_envvars: None) -> None:
